@@ -19,7 +19,17 @@
 #' @return A data frame of indices related to the model's parameters.
 #' @inheritParams simulate_model
 #' @export
-model_parameters.zeroinfl <- function(model, ci = .95, bootstrap = FALSE, iterations = 1000, component = c("all", "conditional", "zi", "zero_inflated"), standardize = NULL, exponentiate = FALSE, robust = FALSE, p_adjust = NULL, ...) {
+model_parameters.zeroinfl <- function(model,
+                                      ci = .95,
+                                      bootstrap = FALSE,
+                                      iterations = 1000,
+                                      component = c("all", "conditional", "zi", "zero_inflated"),
+                                      standardize = NULL,
+                                      exponentiate = FALSE,
+                                      robust = FALSE,
+                                      p_adjust = NULL,
+                                      verbose = TRUE,
+                                      ...) {
   component <- match.arg(component)
 
   # fix argument, if model has no zi-part
@@ -32,12 +42,21 @@ model_parameters.zeroinfl <- function(model, ci = .95, bootstrap = FALSE, iterat
   if (bootstrap) {
     parameters <- bootstrap_parameters(model, iterations = iterations, ci = ci, ...)
   } else {
-    parameters <- .extract_parameters_generic(model, ci = ci, component = component, standardize = standardize, robust = robust, p_adjust = p_adjust, ...)
+    parameters <-
+      .extract_parameters_generic(
+        model,
+        ci = ci,
+        component = component,
+        standardize = standardize,
+        robust = robust,
+        p_adjust = p_adjust,
+        ...
+      )
   }
 
 
   if (exponentiate) parameters <- .exponentiate_parameters(parameters)
-  parameters <- .add_model_parameters_attributes(parameters, model, ci, exponentiate, ...)
+  parameters <- .add_model_parameters_attributes(parameters, model, ci, exponentiate, verbose = verbose, ...)
   attr(parameters, "object_name") <- deparse(substitute(model), width.cutoff = 500)
   class(parameters) <- c("parameters_model", "see_parameters_model", class(parameters))
 
